@@ -1,9 +1,6 @@
 import os
 import pytest
-try:
-    from collections import OrderedDict
-except ImportError: #python 2.6
-    from ordereddict import OrderedDict
+from collections import OrderedDict
 import threading
 from pyfaidx import Fasta
 import random
